@@ -1,5 +1,5 @@
 package Dist::Build::Serializer;
-$Dist::Build::Serializer::VERSION = '0.005';
+$Dist::Build::Serializer::VERSION = '0.006';
 use strict;
 use warnings;
 
@@ -24,40 +24,44 @@ sub deserialize_action {
 	my ($self, $serialized, %options) = @_;
 	my ($command, @args) = @{$serialized};
 
+	my $message = join ' ', @{$serialized};
 	if ($command eq 'tap_harness') {
 		my %args = @args;
 		$args{verbose} = $options{verbose} if defined $options{verbose};
 		$args{jobs} = $options{jobs} if defined $options{jobs};
-		return make_function('tap_harness', %args);
+		return make_function('tap_harness', 'prove', %args);
 	} elsif ($command eq 'copy') {
 		my ($source, $destination, %args) = @args;
 		$args{verbose} = $options{verbose} if defined $options{verbose};
-		return make_function('copy', $source, $destination, %args);
+		$message = sprintf("cp %s %s", $source, $destination);
+		return make_function('copy', "cp $source $destination", $source, $destination, %args);
 	} elsif ($command eq 'mkdir') {
 		my ($destination, %args) = @args;
 		$args{verbose} = $options{verbose} if defined $options{verbose};
-		return make_function('mkdir', $destination, %args);
+		$message = "mkdir $destination";
+		return make_function('mkdir', "mkdir $destination", $destination, %args);
 	} elsif ($command eq 'install') {
 		my %args = @args;
 		$args{verbose} = $options{verbose} if defined $options{verbose};
 		$args{uninst} = $options{uninst} if defined $options{uninst};
 		$args{dry_run} = $options{dry_run} if defined $options{dry_run};
 		$args{install_map} = $options{install_paths}->install_map;
-		return make_function('install', %args);
+		return make_function('install', $message, %args);
 	} elsif (any { $command eq $_ } @Dist::Build::Core::EXPORT_OK) {
-		return make_function($command, @args);
+		return make_function($command, $message, @args);
 	} else {
 		$self->SUPER::deserialize_action($serialized, %options);
 	}
 }
 
 sub make_function {
-	my ($command, @args) = @_;
+	my ($command, $message, @args) = @_;
 	ExtUtils::Builder::Action::Function->new(
 		function  => $command,
 		module    => 'Dist::Build::Core',
 		arguments => \@args,
 		exports   => 'explicit',
+		message   => $message,
 	);
 }
 
@@ -77,7 +81,7 @@ Dist::Build::Serializer - A Serializer for a Dist::Build plan
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 DESCRIPTION
 
